@@ -23,6 +23,7 @@ from __future__ import annotations
 import collections
 import hashlib
 import html.entities
+import importlib.metadata
 import logging
 import os
 import re
@@ -36,18 +37,11 @@ from xml.dom import Node, minidom
 
 import httpx
 
-try:
-    # Python 3.8+
-    import importlib.metadata as importlib_metadata
-except ImportError:
-    # Python 3.7 and lower
-    import importlib_metadata  # type: ignore
-
 __author__ = "Amr Hassan, hugovk, Mice Pápai"
 __copyright__ = "Copyright (C) 2008-2010 Amr Hassan, 2013-2021 hugovk, 2017 Mice Pápai"
 __license__ = "apache2"
 __email__ = "amr.hassan@gmail.com"
-__version__ = importlib_metadata.version(__name__)
+__version__ = importlib.metadata.version(__name__)
 
 
 # 1 : This error does not exist
@@ -546,7 +540,6 @@ class _Network:
         context=None,
         mbid=None,
     ):
-
         """Used to add a track-play to a user's profile.
 
         Parameters:
@@ -600,7 +593,6 @@ class _Network:
 
         params = {}
         for i in range(len(tracks_to_scrobble)):
-
             params[f"artist[{i}]"] = tracks_to_scrobble[i]["artist"]
             params[f"track[{i}]"] = tracks_to_scrobble[i]["title"]
 
@@ -621,7 +613,6 @@ class _Network:
             }
 
             for arg in additional_args:
-
                 if arg in tracks_to_scrobble[i] and tracks_to_scrobble[i][arg]:
                     if arg in args_map_to:
                         maps_to = args_map_to[arg]
@@ -736,7 +727,6 @@ class LibreFMNetwork(_Network):
         username: str = "",
         password_hash: str = "",
     ) -> None:
-
         super().__init__(
             name="Libre.fm",
             homepage="https://libre.fm",
